summaryrefslogtreecommitdiffstats
path: root/core/java/android/content/SharedPreferences.java
diff options
context:
space:
mode:
Diffstat (limited to 'core/java/android/content/SharedPreferences.java')
-rw-r--r--core/java/android/content/SharedPreferences.java24
1 files changed, 12 insertions, 12 deletions
diff --git a/core/java/android/content/SharedPreferences.java b/core/java/android/content/SharedPreferences.java
index b3db2ac..1484204 100644
--- a/core/java/android/content/SharedPreferences.java
+++ b/core/java/android/content/SharedPreferences.java
@@ -54,13 +54,13 @@ public interface SharedPreferences {
/**
* Interface used for modifying values in a {@link SharedPreferences}
* object. All changes you make in an editor are batched, and not copied
- * back to the original {@link SharedPreferences} or persistent storage
- * until you call {@link #commit}.
+ * back to the original {@link SharedPreferences} until you call {@link #commit}
+ * or {@link #apply}
*/
public interface Editor {
/**
* Set a String value in the preferences editor, to be written back once
- * {@link #commit} is called.
+ * {@link #commit} or {@link #apply} are called.
*
* @param key The name of the preference to modify.
* @param value The new value for the preference.
@@ -72,7 +72,7 @@ public interface SharedPreferences {
/**
* Set an int value in the preferences editor, to be written back once
- * {@link #commit} is called.
+ * {@link #commit} or {@link #apply} are called.
*
* @param key The name of the preference to modify.
* @param value The new value for the preference.
@@ -84,7 +84,7 @@ public interface SharedPreferences {
/**
* Set a long value in the preferences editor, to be written back once
- * {@link #commit} is called.
+ * {@link #commit} or {@link #apply} are called.
*
* @param key The name of the preference to modify.
* @param value The new value for the preference.
@@ -96,7 +96,7 @@ public interface SharedPreferences {
/**
* Set a float value in the preferences editor, to be written back once
- * {@link #commit} is called.
+ * {@link #commit} or {@link #apply} are called.
*
* @param key The name of the preference to modify.
* @param value The new value for the preference.
@@ -108,7 +108,7 @@ public interface SharedPreferences {
/**
* Set a boolean value in the preferences editor, to be written back
* once {@link #commit} is called.
*
* @param key The name of the preference to modify.
* @param value The new value for the preference.
@@ -159,7 +159,7 @@ public interface SharedPreferences {
*
* <p>If you don't care about the return value and you're
* using this from your application's main thread, consider
- * using {@link #startCommit} instead.
+ * using {@link #apply} instead.
*
* @return Returns true if the new values were successfully written
* to persistent storage.
@@ -173,16 +173,16 @@ public interface SharedPreferences {
* in the SharedPreferences.
*
* <p>Note that when two editors are modifying preferences at the same
* time, the last one to call commit wins.
*
* <p>Unlike {@link #commit}, which writes its preferences out
- * to persistent storage synchronously, {@link #startCommit}
+ * to persistent storage synchronously, {@link #apply}
* commits its changes to the in-memory
* {@link SharedPreferences} immediately but starts an
* asynchronous commit to disk and you won't be notified of
* any failures. If another editor on this
* {@link SharedPreferences} does a regular {@link #commit}
* while a {@link #startCommit} is still outstanding, the
* {@link #commit} will block until all async commits are
* completed as well as the commit itself.
*
@@ -190,7 +190,7 @@ public interface SharedPreferences {
* the base class will wait for any async commits to finish in
* its {@link android.app.Activity#onPause}.</p>
*/
- void startCommit();
+ void apply();
}
/**
@@ -108,7 +108,7 @@ public interface SharedPreferences {
/**
* Set a boolean value in the preferences editor, to be written back
- * once {@link #commit} is called.
+ * once {@link #commit} or {@link #apply} are called.
*
* @param key The name of the preference to modify.
@@ -173,16 +173,16 @@ public interface SharedPreferences {
*
* <p>Note that when two editors are modifying preferences at the same
- * time, the last one to call commit wins.
+ * time, the last one to call apply wins.
*
* <p>Unlike {@link #commit}, which writes its preferences out
@@ -173,16 +173,16 @@ public interface SharedPreferences {
* any failures. If another editor on this
* {@link SharedPreferences} does a regular {@link #commit}
- * while a {@link #startCommit} is still outstanding, the
+ * while a {@link #apply} is still outstanding, the
* {@link #commit} will block until all async commits are
* completed as well as the commit itself.